You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by ds...@apache.org on 2016/09/15 21:01:54 UTC

[37/76] [abbrv] [partial] incubator-geode git commit: GEODE-37 changed import to org.apache.geode

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/control/package.html
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/control/package.html b/geode-core/src/main/java/org/apache/geode/cache/control/package.html
index 74c0aa0..4cc3920 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/control/package.html
+++ b/geode-core/src/main/java/org/apache/geode/cache/control/package.html
@@ -17,7 +17,7 @@ limitations under the License.
 <html>
 <body>
 
-<p>Controls the resources used by the local GemFire <code>Cache</code>. The {@linkplain com.gemstone.gemfire.cache.control.ResourceManager} exposes options affecting how the resources are controlled. Additionally, <code>Cache</code> resources can also be rebalanced across the GemFire distributed system.</p>
+<p>Controls the resources used by the local GemFire <code>Cache</code>. The {@linkplain org.apache.geode.cache.control.ResourceManager} exposes options affecting how the resources are controlled. Additionally, <code>Cache</code> resources can also be rebalanced across the GemFire distributed system.</p>
 
 </body>
 </html>

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/execute/EmptyRegionFunctionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/execute/EmptyRegionFunctionException.java b/geode-core/src/main/java/org/apache/geode/cache/execute/EmptyRegionFunctionException.java
index ddb49b3..bdafb89 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/execute/EmptyRegionFunctionException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/execute/EmptyRegionFunctionException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.execute;
+package org.apache.geode.cache.execute;
 
-import com.gemstone.gemfire.distributed.DistributedMember;
+import org.apache.geode.distributed.DistributedMember;
 
 /**
  * Exception to indicate that Region is empty for data aware functions.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/execute/Execution.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/execute/Execution.java b/geode-core/src/main/java/org/apache/geode/cache/execute/Execution.java
index 41b1097..50a312d 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/execute/Execution.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/execute/Execution.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.execute;
+package org.apache.geode.cache.execute;
 
 import java.util.Set;
 
-import com.gemstone.gemfire.cache.DataPolicy;
-import com.gemstone.gemfire.cache.LowMemoryException;
+import org.apache.geode.cache.DataPolicy;
+import org.apache.geode.cache.LowMemoryException;
 
 /**
  * Provides methods to build the context for the execution of a {@link Function}
@@ -49,7 +49,7 @@ public interface Execution {
    *           if filter passed is null.
    * @throws UnsupportedOperationException
    *           if not called after
-   *           {@link FunctionService#onRegion(com.gemstone.gemfire.cache.Region)}
+   *           {@link FunctionService#onRegion(org.apache.geode.cache.Region)}
    * @since GemFire 6.0
    */
   public Execution withFilter(Set<?> filter);

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/execute/Function.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionAdapter.java b/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionAdapter.java
index 7ee262a..29b63f3 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionAdapter.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionAdapter.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.execute;
+package org.apache.geode.cache.execute;
 
 /**
  * Application developers can extend this class instead of implementing the

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionContext.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionContext.java b/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionContext.java
index 844e4c8..fc85684 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionContext.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.execute;
+package org.apache.geode.cache.execute;
 
 /**
  * Defines the execution context of a {@link Function}. It is required

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionException.java b/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionException.java
index b6f017c..d0305a7 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionException.java
@@ -15,14 +15,14 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.execute;
+package org.apache.geode.cache.execute;
 
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 
-import com.gemstone.gemfire.GemFireException;
-import com.gemstone.gemfire.internal.Assert;
+import org.apache.geode.GemFireException;
+import org.apache.geode.internal.Assert;
 
 /**
  * Thrown to indicate an error or exceptional condition during the execution of 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionInvocationTargetException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionInvocationTargetException.java b/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionInvocationTargetException.java
index 392db12..15343c6 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionInvocationTargetException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionInvocationTargetException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.execute;
+package org.apache.geode.cache.execute;
 
-import com.gemstone.gemfire.distributed.DistributedMember;
+import org.apache.geode.distributed.DistributedMember;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionService.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionService.java b/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionService.java
index 5536978..2eb715d 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionService.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionService.java
@@ -14,23 +14,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.execute;
+package org.apache.geode.cache.execute;
 
 import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
 
-import com.gemstone.gemfire.cache.Region;
-import com.gemstone.gemfire.cache.RegionService;
-import com.gemstone.gemfire.cache.client.ClientCache;
-import com.gemstone.gemfire.cache.client.ClientCacheFactory;
-import com.gemstone.gemfire.cache.client.Pool;
-import com.gemstone.gemfire.cache.execute.internal.FunctionServiceManager;
-import com.gemstone.gemfire.distributed.DistributedMember;
-import com.gemstone.gemfire.distributed.DistributedSystem;
-import com.gemstone.gemfire.distributed.DistributedSystemDisconnectedException;
-import com.gemstone.gemfire.distributed.internal.InternalDistributedSystem;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.cache.Region;
+import org.apache.geode.cache.RegionService;
+import org.apache.geode.cache.client.ClientCache;
+import org.apache.geode.cache.client.ClientCacheFactory;
+import org.apache.geode.cache.client.Pool;
+import org.apache.geode.cache.execute.internal.FunctionServiceManager;
+import org.apache.geode.distributed.DistributedMember;
+import org.apache.geode.distributed.DistributedSystem;
+import org.apache.geode.distributed.DistributedSystemDisconnectedException;
+import org.apache.geode.distributed.internal.InternalDistributedSystem;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 /**
  * Provides the entry point into execution of user defined {@linkplain Function}s.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/execute/RegionFunctionContext.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/execute/RegionFunctionContext.java b/geode-core/src/main/java/org/apache/geode/cache/execute/RegionFunctionContext.java
index a5f90d9..149e7d6 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/execute/RegionFunctionContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/execute/RegionFunctionContext.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.execute;
+package org.apache.geode.cache.execute;
 
 import java.util.Set;
 
-import com.gemstone.gemfire.cache.PartitionAttributesFactory;
-import com.gemstone.gemfire.cache.Region;
-import com.gemstone.gemfire.cache.partition.PartitionRegionHelper;
+import org.apache.geode.cache.PartitionAttributesFactory;
+import org.apache.geode.cache.Region;
+import org.apache.geode.cache.partition.PartitionRegionHelper;
 
 /**
  * Defines the execution context of a data dependent {@link Function}.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/execute/ResultCollector.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/execute/ResultCollector.java b/geode-core/src/main/java/org/apache/geode/cache/execute/ResultCollector.java
index 32b7545..5fc5628 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/execute/ResultCollector.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/execute/ResultCollector.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.execute;
+package org.apache.geode.cache.execute;
 
 import java.util.concurrent.TimeUnit;
 
-import com.gemstone.gemfire.distributed.DistributedMember;
+import org.apache.geode.distributed.DistributedMember;
 
 /**
  * <p>

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/execute/ResultSender.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/execute/ResultSender.java b/geode-core/src/main/java/org/apache/geode/cache/execute/ResultSender.java
index ee02258..28952df 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/execute/ResultSender.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/execute/ResultSender.java
@@ -15,14 +15,14 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.execute;
+package org.apache.geode.cache.execute;
 
 /**
  * Provides methods to send results back to the ResultCollector. A ResultSender
  * adds the ability for an execute method to send a single result back, or break
  * its result into multiple pieces and send each piece back to the calling
  * thread's {@link ResultCollector}. For each result sent using this method,
- * {@link ResultCollector#addResult(com.gemstone.gemfire.distributed.DistributedMember, Object)} is called,
+ * {@link ResultCollector#addResult(org.apache.geode.distributed.DistributedMember, Object)} is called,
  * making that result available to the calling thread immediately.
  * 
  * <p>
@@ -48,13 +48,13 @@ package com.gemstone.gemfire.cache.execute;
  * 
  * @since GemFire 6.0
  * 
- * @see ResultCollector#addResult(com.gemstone.gemfire.distributed.DistributedMember, Object)
+ * @see ResultCollector#addResult(org.apache.geode.distributed.DistributedMember, Object)
  * 
  */
 public interface ResultSender<T> {
   /**
    * Sends a result back to the FunctionService calling thread and invokes
-   * {@link ResultCollector#addResult(com.gemstone.gemfire.distributed.DistributedMember, Object)}.
+   * {@link ResultCollector#addResult(org.apache.geode.distributed.DistributedMember, Object)}.
    * 
    * @param oneResult
    */
@@ -62,7 +62,7 @@ public interface ResultSender<T> {
 
   /**
    * Sends a result back to the FunctionService calling thread and invokes
-   * {@link ResultCollector#addResult(com.gemstone.gemfire.distributed.DistributedMember, Object)} and then
+   * {@link ResultCollector#addResult(org.apache.geode.distributed.DistributedMember, Object)} and then
    * {@link ResultCollector#endResults()} if it is the last instance of the
    * Function to report results. The ResultCollector will keep waiting for
    * results until it receives last result. Therefore, it is very important to

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/execute/internal/FunctionServiceManager.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/execute/internal/FunctionServiceManager.java b/geode-core/src/main/java/org/apache/geode/cache/execute/internal/FunctionServiceManager.java
index 32756ea..f0688bc 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/execute/internal/FunctionServiceManager.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/execute/internal/FunctionServiceManager.java
@@ -14,29 +14,29 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.execute.internal;
+package org.apache.geode.cache.execute.internal;
 
-import com.gemstone.gemfire.cache.Region;
-import com.gemstone.gemfire.cache.RegionService;
-import com.gemstone.gemfire.cache.client.ClientCache;
-import com.gemstone.gemfire.cache.client.ClientCacheFactory;
-import com.gemstone.gemfire.cache.client.Pool;
-import com.gemstone.gemfire.cache.client.PoolManager;
-import com.gemstone.gemfire.cache.client.internal.ProxyCache;
-import com.gemstone.gemfire.cache.client.internal.ProxyRegion;
-import com.gemstone.gemfire.cache.execute.Execution;
-import com.gemstone.gemfire.cache.execute.Function;
-import com.gemstone.gemfire.cache.execute.FunctionException;
-import com.gemstone.gemfire.cache.execute.FunctionService;
-import com.gemstone.gemfire.cache.partition.PartitionRegionHelper;
-import com.gemstone.gemfire.distributed.DistributedMember;
-import com.gemstone.gemfire.distributed.DistributedSystem;
-import com.gemstone.gemfire.distributed.internal.DistributionConfig;
-import com.gemstone.gemfire.internal.InternalEntity;
-import com.gemstone.gemfire.internal.cache.GemFireCacheImpl;
-import com.gemstone.gemfire.internal.cache.LocalRegion;
-import com.gemstone.gemfire.internal.cache.execute.*;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.cache.Region;
+import org.apache.geode.cache.RegionService;
+import org.apache.geode.cache.client.ClientCache;
+import org.apache.geode.cache.client.ClientCacheFactory;
+import org.apache.geode.cache.client.Pool;
+import org.apache.geode.cache.client.PoolManager;
+import org.apache.geode.cache.client.internal.ProxyCache;
+import org.apache.geode.cache.client.internal.ProxyRegion;
+import org.apache.geode.cache.execute.Execution;
+import org.apache.geode.cache.execute.Function;
+import org.apache.geode.cache.execute.FunctionException;
+import org.apache.geode.cache.execute.FunctionService;
+import org.apache.geode.cache.partition.PartitionRegionHelper;
+import org.apache.geode.distributed.DistributedMember;
+import org.apache.geode.distributed.DistributedSystem;
+import org.apache.geode.distributed.internal.DistributionConfig;
+import org.apache.geode.internal.InternalEntity;
+import org.apache.geode.internal.cache.GemFireCacheImpl;
+import org.apache.geode.internal.cache.LocalRegion;
+import org.apache.geode.internal.cache.execute.*;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 import java.util.*;
 import java.util.concurrent.ConcurrentHashMap;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/execute/package.html
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/execute/package.html b/geode-core/src/main/java/org/apache/geode/cache/execute/package.html
index f66eec4..ce3046e 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/execute/package.html
+++ b/geode-core/src/main/java/org/apache/geode/cache/execute/package.html
@@ -17,11 +17,11 @@ limitations under the License.
 -->
 <HTML>
   <HEAD>
-    <TITLE>com.gemstone.gemfire.cache.execute package</TITLE>
+    <TITLE>org.apache.geode.cache.execute package</TITLE>
   </HEAD>
   <BODY>
   <p>
-  The <code>com.gemstone.gemfire.cache.execute</code> package provides APIs used
+  The <code>org.apache.geode.cache.execute</code> package provides APIs used
   for function execution on gemfire system members.
   </p>
   <p>
@@ -41,10 +41,10 @@ limitations under the License.
 	<li>The FunctionService class provides methods to execute functions on targeted GemFire 
 	 system members.</li>
 
-	<li>Functions are java classes that implement the {@link com.gemstone.gemfire.cache.execute.Function} interface. Functions
-	can be registered with the {@linkplain com.gemstone.gemfire.cache.execute.FunctionService Function Execution Service}.</li>
+	<li>Functions are java classes that implement the {@link org.apache.geode.cache.execute.Function} interface. Functions
+	can be registered with the {@linkplain org.apache.geode.cache.execute.FunctionService Function Execution Service}.</li>
 	
-	<li>The application obtains the execution object {@link com.gemstone.gemfire.cache.execute.Execution} and uses its methods to target 
+	<li>The application obtains the execution object {@link org.apache.geode.cache.execute.Execution} and uses its methods to target 
 	execution.</li>
 	
         <li>Calling the execute() method on the Execution object

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/CloseCQOperationContext.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/ExecuteCQOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/ExecuteCQOperationContext.java
index a2b8ab2..a77dd32 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/ExecuteCQOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/ExecuteCQOperationContext.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 import java.util.Set;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/ExecuteFunctionOperationContext.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/ExecuteFunctionOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/ExecuteFunctionOperationContext.java
index dafc5c0..187612f 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/ExecuteFunctionOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/ExecuteFunctionOperationContext.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 import java.io.Serializable;
 import java.util.Set;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/GetDurableCQsOperationContext.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/InterestOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/InterestOperationContext.java
index 2cdd13e..bb2a993 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/InterestOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/InterestOperationContext.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/InterestType.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/InterestType.java b/geode-core/src/main/java/org/apache/geode/cache/operations/InterestType.java
index 906125d..e8ceb17 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/InterestType.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/InterestType.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 /**
  * Enumeration for various interest types supported by GemFire.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/InvalidateOperationContext.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/KeyValueOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/KeyValueOperationContext.java
index 415f842..e993409 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/KeyValueOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/KeyValueOperationContext.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
-import com.gemstone.gemfire.DataSerializer;
-import com.gemstone.gemfire.SerializationException;
-import com.gemstone.gemfire.internal.cache.EntryEventImpl;
+import org.apache.geode.DataSerializer;
+import org.apache.geode.SerializationException;
+import org.apache.geode.internal.cache.EntryEventImpl;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/OperationContext.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/OperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/OperationContext.java
index 3a7d34c..b8d0e93 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/OperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/OperationContext.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 import org.apache.geode.security.ResourcePermission;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/PutAllOperationContext.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/QueryOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/QueryOperationContext.java
index 9113f79..917cb08 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/QueryOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/QueryOperationContext.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 import java.util.Set;
 
-import com.gemstone.gemfire.cache.operations.OperationContext;
+import org.apache.geode.cache.operations.OperationContext;
 
 /**
  * Encapsulates a cache query operation for both the pre-operation and

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/RegionClearOperationContext.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/internal/GetOperationContextImpl.java b/geode-core/src/main/java/org/apache/geode/cache/operations/internal/GetOperationContextImpl.java
index 2904776..82716ad 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/internal/GetOperationContextImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/internal/GetOperationContextImpl.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.operations.internal;
+package org.apache.geode.cache.operations.internal;
 
-import com.gemstone.gemfire.SerializationException;
-import com.gemstone.gemfire.cache.operations.GetOperationContext;
-import com.gemstone.gemfire.internal.offheap.Releasable;
-import com.gemstone.gemfire.internal.offheap.StoredObject;
-import com.gemstone.gemfire.internal.offheap.annotations.Unretained;
+import org.apache.geode.SerializationException;
+import org.apache.geode.cache.operations.GetOperationContext;
+import org.apache.geode.internal.offheap.Releasable;
+import org.apache.geode.internal.offheap.StoredObject;
+import org.apache.geode.internal.offheap.annotations.Unretained;
 
 /**
  * This subclass's job is to keep customers from getting a reference to a value

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/internal/UpdateOnlyMap.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/internal/UpdateOnlyMap.java b/geode-core/src/main/java/org/apache/geode/cache/operations/internal/UpdateOnlyMap.java
index 843e75d..2bbc3cd 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/internal/UpdateOnlyMap.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/internal/UpdateOnlyMap.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.operations.internal;
+package org.apache.geode.cache.operations.internal;
 
 import java.io.Serializable;
 
@@ -28,8 +28,8 @@ import java.util.Objects;
 import java.util.Set;
 import java.util.Map.Entry;
 
-import com.gemstone.gemfire.internal.cache.CachedDeserializable;
-import com.gemstone.gemfire.internal.cache.Token;
+import org.apache.geode.internal.cache.CachedDeserializable;
+import org.apache.geode.internal.cache.Token;
 
 /**
  * This map only allows updates. No creates or removes.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/package.html
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/package.html b/geode-core/src/main/java/org/apache/geode/cache/operations/package.html
index c7ad91b..131a7a2 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/package.html
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/package.html
@@ -18,89 +18,89 @@ limitations under the License.
 <BODY>
 
 
-<P>Contains the {@link com.gemstone.gemfire.cache.operations.OperationContext} interface that encapsulates an operation and the data associated with it for both the pre-operation and post-operation cases. 
-It also contains implementations of the {@link com.gemstone.gemfire.cache.operations.OperationContext} interface for  various kinds of cache operations.</P> 
+<P>Contains the {@link org.apache.geode.cache.operations.OperationContext} interface that encapsulates an operation and the data associated with it for both the pre-operation and post-operation cases. 
+It also contains implementations of the {@link org.apache.geode.cache.operations.OperationContext} interface for  various kinds of cache operations.</P> 
 
 These include: 
 	
 
-<P> {@link com.gemstone.gemfire.cache.operations.KeyOperationContext}: Implementation for operations that require a key for the operation. 
+<P> {@link org.apache.geode.cache.operations.KeyOperationContext}: Implementation for operations that require a key for the operation. 
 It provides a getKey method to obtain the key. Also provided are setCallbackArg and getCallbackArg methods that can be used to set/get an optional callback argument. 
-The operations returned as KeyOperationContext are {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#DESTROY} 
-and {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#CONTAINS_KEY}. 
+The operations returned as KeyOperationContext are {@link org.apache.geode.cache.operations.OperationContext.OperationCode#DESTROY} 
+and {@link org.apache.geode.cache.operations.OperationContext.OperationCode#CONTAINS_KEY}. 
 </P>
 
-<P> {@link com.gemstone.gemfire.cache.operations.KeyValueOperationContext}: Implementation for operations that require both key and value for the operation. 
-It extends the {@link com.gemstone.gemfire.cache.operations.KeyOperationContext} implementation providing getValue and setValue methods
+<P> {@link org.apache.geode.cache.operations.KeyValueOperationContext}: Implementation for operations that require both key and value for the operation. 
+It extends the {@link org.apache.geode.cache.operations.KeyOperationContext} implementation providing getValue and setValue methods
 in addition to those provided by the KeyOperationContext class. 
-The operations returned as KeyValueOperationContext are {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#GET} and {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#PUT}. 
+The operations returned as KeyValueOperationContext are {@link org.apache.geode.cache.operations.OperationContext.OperationCode#GET} and {@link org.apache.geode.cache.operations.OperationContext.OperationCode#PUT}. 
 For the GET operation this is used to both the pre and post operation cases. </P>
 
-<P>{@link com.gemstone.gemfire.cache.operations.InterestOperationContext}: Implementation for register and unregister of interest in a region. 
-It defines a sub-class {@link com.gemstone.gemfire.cache.operations.InterestType} that encapsulates different kinds of interest viz. 
+<P>{@link org.apache.geode.cache.operations.InterestOperationContext}: Implementation for register and unregister of interest in a region. 
+It defines a sub-class {@link org.apache.geode.cache.operations.InterestType} that encapsulates different kinds of interest viz. 
 KEY, LIST, REGULAR_EXPRESSION, FILTER_CLASS and OQL_QUERY. 
 It provides getInterestType method to get the interest type, 
-getInterestResultPolicy method to get the {@link com.gemstone.gemfire.cache.InterestResultPolicy} of the request, 
+getInterestResultPolicy method to get the {@link org.apache.geode.cache.InterestResultPolicy} of the request, 
 isUnregister method that returns true if this is an unregister operation, and getKey/setKey methods to get/set the key being registered. 
-The key may be a single key, a list of keys, a regular expression string or an OQL {@link com.gemstone.gemfire.cache.query.Query}. </P>
+The key may be a single key, a list of keys, a regular expression string or an OQL {@link org.apache.geode.cache.query.Query}. </P>
 
-<P> {@link com.gemstone.gemfire.cache.operations.QueryOperationContext}: Implementation for a cache query operation for both the pre and post operation cases. 
+<P> {@link org.apache.geode.cache.operations.QueryOperationContext}: Implementation for a cache query operation for both the pre and post operation cases. 
 It provides getQuery to get the query string as well as a modifyQuery method to be able to modify it. 
 A utility getRegionNames method is also provided to obtain the list of regions as referenced by the query string. 
 For the results in the post operation phase, getQueryResult allows getting the result and setQueryResult allows modification of the result.</P>
 	
 
-<P> {@link com.gemstone.gemfire.cache.operations.RegionOperationContext}: Implementation for the region level operation for the pre operation case. 
+<P> {@link org.apache.geode.cache.operations.RegionOperationContext}: Implementation for the region level operation for the pre operation case. 
 It provides getCallbackArg and setCallbackArg methods to get/set the optionally callback argument. 
-The operations returned as RegionOperationContext are {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_CLEAR} 
-and {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_DESTROY}.</P> 
+The operations returned as RegionOperationContext are {@link org.apache.geode.cache.operations.OperationContext.OperationCode#REGION_CLEAR} 
+and {@link org.apache.geode.cache.operations.OperationContext.OperationCode#REGION_DESTROY}.</P> 
 	
 
-<P> {@link com.gemstone.gemfire.cache.operations.DestroyOperationContext}: Implementation for {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#DESTROY} operation 
+<P> {@link org.apache.geode.cache.operations.DestroyOperationContext}: Implementation for {@link org.apache.geode.cache.operations.OperationContext.OperationCode#DESTROY} operation 
 having the key object for both the pre-operation and post-operation updates.
 </P>	
 
-<P> {@link com.gemstone.gemfire.cache.operations.CloseCQOperationContext}: Implementation for {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#CLOSE_CQ} operation
+<P> {@link org.apache.geode.cache.operations.CloseCQOperationContext}: Implementation for {@link org.apache.geode.cache.operations.OperationContext.OperationCode#CLOSE_CQ} operation
 for the pre-operation case.
 </P>
 
-<P> {@link com.gemstone.gemfire.cache.operations.ExecuteCQOperationContext}: Implementation for {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#EXECUTE_CQ} operation 
+<P> {@link org.apache.geode.cache.operations.ExecuteCQOperationContext}: Implementation for {@link org.apache.geode.cache.operations.OperationContext.OperationCode#EXECUTE_CQ} operation 
 for both the pre-operation and post-operation case.</P>
 
-<P> {@link com.gemstone.gemfire.cache.operations.ExecuteFunctionOperationContext}: Implementation for {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#EXECUTE_FUNCTION} operation 
+<P> {@link org.apache.geode.cache.operations.ExecuteFunctionOperationContext}: Implementation for {@link org.apache.geode.cache.operations.OperationContext.OperationCode#EXECUTE_FUNCTION} operation 
 for the pre-operation  case.
 </P>
 
-<P> {@link com.gemstone.gemfire.cache.operations.GetOperationContext}: Implementation for {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#GET} operation 
+<P> {@link org.apache.geode.cache.operations.GetOperationContext}: Implementation for {@link org.apache.geode.cache.operations.OperationContext.OperationCode#GET} operation 
 having the key object for the pre-operation case and both key-value objects for the post-operation case.
 </P>
 
-<P> {@link com.gemstone.gemfire.cache.operations.InvalidateOperationContext}: Implementation for {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#INVALIDATE} region
+<P> {@link org.apache.geode.cache.operations.InvalidateOperationContext}: Implementation for {@link org.apache.geode.cache.operations.OperationContext.OperationCode#INVALIDATE} region
 operation having the key object for the pre-operation case and post-operation case.
 </P>
 
-<P> {@link com.gemstone.gemfire.cache.operations.PutOperationContext}: Implementation for {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#PUT} operation 
+<P> {@link org.apache.geode.cache.operations.PutOperationContext}: Implementation for {@link org.apache.geode.cache.operations.OperationContext.OperationCode#PUT} operation 
 having the key and value objects for the pre-operation case and post-operation case.
 </P>
 
-<P> {@link com.gemstone.gemfire.cache.operations.PutAllOperationContext}: Implementation for {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#KEY_SET} operation
+<P> {@link org.apache.geode.cache.operations.PutAllOperationContext}: Implementation for {@link org.apache.geode.cache.operations.OperationContext.OperationCode#KEY_SET} operation
 having the key and value objects for the pre-operation case and post-operation case.
 </P>
 
-<P> {@link com.gemstone.gemfire.cache.operations.RegionCreateOperationContext}: Implementation for {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_CREATE} 
+<P> {@link org.apache.geode.cache.operations.RegionCreateOperationContext}: Implementation for {@link org.apache.geode.cache.operations.OperationContext.OperationCode#REGION_CREATE} 
 operation for the pre-operation case and post-operation case.
 </P>
 
-<P> {@link com.gemstone.gemfire.cache.operations.StopCQOperationContext}: Implementation for {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#STOP_CQ} operation
+<P> {@link org.apache.geode.cache.operations.StopCQOperationContext}: Implementation for {@link org.apache.geode.cache.operations.OperationContext.OperationCode#STOP_CQ} operation
 for the pre-operation case.
 </P>
 
-<P> {@link com.gemstone.gemfire.cache.operations.RegisterInterestOperationContext}: Implementation for {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGISTER_INTEREST} operation
-for the pre-operation case, which derives from {@link com.gemstone.gemfire.cache.operations.InterestOperationContext}
+<P> {@link org.apache.geode.cache.operations.RegisterInterestOperationContext}: Implementation for {@link org.apache.geode.cache.operations.OperationContext.OperationCode#REGISTER_INTEREST} operation
+for the pre-operation case, which derives from {@link org.apache.geode.cache.operations.InterestOperationContext}
  </P>
 
-<P> {@link com.gemstone.gemfire.cache.operations.UnregisterInterestOperationContext}: Implementation for {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#UNREGISTER_INTEREST} operation 
-for the pre-operation case, which derives from {@link com.gemstone.gemfire.cache.operations.InterestOperationContext} </P>
+<P> {@link org.apache.geode.cache.operations.UnregisterInterestOperationContext}: Implementation for {@link org.apache.geode.cache.operations.OperationContext.OperationCode#UNREGISTER_INTEREST} operation 
+for the pre-operation case, which derives from {@link org.apache.geode.cache.operations.InterestOperationContext} </P>
 
 
 </BODY>
diff --git a/geode-core/src/main/java/org/apache/geode/cache/execute/Function.java b/geode-core/src/main/java/org/apache/geode/cache/execute/Function.java
index 79364a9..14b0f9a 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/execute/Function.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/execute/Function.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.execute;
+package org.apache.geode.cache.execute;
 
-import com.gemstone.gemfire.cache.Region;
-import com.gemstone.gemfire.lang.Identifiable;
+import org.apache.geode.cache.Region;
+import org.apache.geode.lang.Identifiable;
 
 /**
  * Defines the interface a user defined function implements.
@@ -84,15 +84,15 @@ public interface Function extends Identifiable<String> {
 
   /**
    * <p>Return true to indicate to GemFire the method
    * requires optimization for writing the targeted {@link FunctionService#onRegion(com.gemstone.gemfire.cache.Region)} and any
    * associated {@linkplain Execution#withFilter(java.util.Set) routing objects}.</p>
    *
    * <p>Returning false will optimize for read behavior on the targeted
-   * {@link FunctionService#onRegion(com.gemstone.gemfire.cache.Region)} and any
+   * {@link FunctionService#onRegion(org.apache.geode.cache.Region)} and any
    * associated {@linkplain Execution#withFilter(java.util.Set) routing objects}.</p>
    *
    * <p>This method is only consulted when Region passed to 
    * FunctionService#onRegion(com.gemstone.gemfire.cache.Region) is a partitioned region
    * </p>
    *
    * @return false if the function is read only, otherwise returns true

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/execute/FunctionAdapter.java
----------------------------------------------------------------------
@@ -84,15 +84,15 @@ public interface Function extends Identifiable<String> {
   /**
    * <p>Return true to indicate to GemFire the method
-   * requires optimization for writing the targeted {@link FunctionService#onRegion(com.gemstone.gemfire.cache.Region)} and any
+   * requires optimization for writing the targeted {@link FunctionService#onRegion(org.apache.geode.cache.Region)} and any
    * associated {@linkplain Execution#withFilter(java.util.Set) routing objects}.</p>
    *
@@ -84,15 +84,15 @@ public interface Function extends Identifiable<String> {
    *
    * <p>This method is only consulted when Region passed to 
-   * FunctionService#onRegion(com.gemstone.gemfire.cache.Region) is a partitioned region
+   * FunctionService#onRegion(org.apache.geode.cache.Region) is a partitioned region
    * </p>
    *
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/CloseCQOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/CloseCQOperationContext.java
index 1924605..aa38d32 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/CloseCQOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/CloseCQOperationContext.java
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 import java.util.Set;
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#CLOSE_CQ} operation for the pre-operation
  * case.
  * 
  * @since GemFire 5.5

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/DestroyOperationContext.java
----------------------------------------------------------------------
@@ -15,12 +15,12 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#CLOSE_CQ} operation for the pre-operation
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#CLOSE_CQ} operation for the pre-operation
  * case.
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/DestroyOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/DestroyOperationContext.java
index c00b1a7..2c37dc2 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/DestroyOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/DestroyOperationContext.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#DESTROY} region operation having the key
  * object for both the pre-operation case and for post-operation updates.
  * 
  * @since GemFire 5.5

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/ExecuteCQOperationContext.java
----------------------------------------------------------------------
@@ -15,11 +15,11 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#DESTROY} region operation having the key
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#DESTROY} region operation having the key
  * object for both the pre-operation case and for post-operation updates.
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/GetDurableCQsOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/GetDurableCQsOperationContext.java
index abec6b6..4f1dff2 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/GetDurableCQsOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/GetDurableCQsOperationContext.java
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 import java.util.Set;
 
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#GET_DURABLE_CQS} operation for the pre-operation
  * case.
  * 
  * @since GemFire 7.0

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/GetOperationContext.java
----------------------------------------------------------------------
@@ -15,13 +15,13 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#GET_DURABLE_CQS} operation for the pre-operation
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#GET_DURABLE_CQS} operation for the pre-operation
  * case.
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/GetOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/GetOperationContext.java
index f276d2c..291afbd 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/GetOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/GetOperationContext.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#GET} region operation having the key
  * object for the pre-operation case and both key, value objects for the
  * post-operation case.
  * 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/InterestOperationContext.java
----------------------------------------------------------------------
@@ -15,11 +15,11 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#GET} region operation having the key
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#GET} region operation having the key
  * object for the pre-operation case and both key, value objects for the
  * post-operation case.
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/InvalidateOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/InvalidateOperationContext.java
index dd8ce38..e024df3 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/InvalidateOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/InvalidateOperationContext.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#INVALIDATE} region operation having the key
  * object for both the pre-operation case and for post-operation updates.
  * 
  * @since GemFire 5.5

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/KeyOperationContext.java
----------------------------------------------------------------------
@@ -15,11 +15,11 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#INVALIDATE} region operation having the key
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#INVALIDATE} region operation having the key
  * object for both the pre-operation case and for post-operation updates.
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/KeyOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/KeyOperationContext.java
index 985af0b..e2b09a3 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/KeyOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/KeyOperationContext.java
@@ -15,14 +15,14 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 
 /**
  * Encapsulates a region operation that requires only a key object for the
  * pre-operation case. The operations this class encapsulates are
- * {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#DESTROY} 
- * and {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#CONTAINS_KEY}.
+ * {@link org.apache.geode.cache.operations.OperationContext.OperationCode#DESTROY} 
+ * and {@link org.apache.geode.cache.operations.OperationContext.OperationCode#CONTAINS_KEY}.
  * 
  * @since GemFire 5.5
  */
@@ -68,11 +68,11 @@ public abstract class KeyOperationContext extends OperationContext {
    * object.
    * 
    * @return The <code>OperationCode</code> of this operation. This is one of
-   *         {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#DESTROY} 
-   *         or {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#CONTAINS_KEY}
+   *         {@link org.apache.geode.cache.operations.OperationContext.OperationCode#DESTROY} 
+   *         or {@link org.apache.geode.cache.operations.OperationContext.OperationCode#CONTAINS_KEY}
    *         for <code>KeyOperationContext</code>, and one of
    *         {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#GET} or 
    *         {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#PUT} for
    *         <code>KeyValueOperationContext</code>.
    */
   @Override

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/KeySetOperationContext.java
----------------------------------------------------------------------
@@ -68,11 +68,11 @@ public abstract class KeyOperationContext extends OperationContext {
    *         for <code>KeyOperationContext</code>, and one of
-   *         {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#GET} or 
-   *         {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#PUT} for
+   *         {@link org.apache.geode.cache.operations.OperationContext.OperationCode#GET} or 
+   *         {@link org.apache.geode.cache.operations.OperationContext.OperationCode#PUT} for
    *         <code>KeyValueOperationContext</code>.
    */
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/KeySetOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/KeySetOperationContext.java
index 0b8bccc..2eb14ff 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/KeySetOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/KeySetOperationContext.java
@@ -15,15 +15,15 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 import java.util.Set;
 
-import com.gemstone.gemfire.cache.Region;
-import com.gemstone.gemfire.cache.operations.OperationContext;
+import org.apache.geode.cache.Region;
+import org.apache.geode.cache.operations.OperationContext;
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#KEY_SET} operation for both the
  * pre-operation and post-operation cases.
  * 
  * @since GemFire 5.5

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/KeyValueOperationContext.java
----------------------------------------------------------------------
@@ -15,15 +15,15 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#KEY_SET} operation for both the
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#KEY_SET} operation for both the
  * pre-operation and post-operation cases.
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/PutAllOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/PutAllOperationContext.java
index d8acba9..122bdfa 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/PutAllOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/PutAllOperationContext.java
@@ -15,15 +15,15 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 import java.util.Map;
 
-import com.gemstone.gemfire.cache.operations.OperationContext;
-import com.gemstone.gemfire.cache.operations.internal.UpdateOnlyMap;
+import org.apache.geode.cache.operations.OperationContext;
+import org.apache.geode.cache.operations.internal.UpdateOnlyMap;
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#PUTALL} operation for both the
  * pre-operation and post-operation cases.
  * 
  * @since GemFire 5.7

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/PutOperationContext.java
----------------------------------------------------------------------
@@ -15,15 +15,15 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#PUTALL} operation for both the
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#PUTALL} operation for both the
  * pre-operation and post-operation cases.
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/PutOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/PutOperationContext.java
index de24fd1..49af7ef 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/PutOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/PutOperationContext.java
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
-import com.gemstone.gemfire.cache.Region;
+import org.apache.geode.cache.Region;
 
 /**
  * Encapsulates an {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#PUT} region operation having both key
  * and value objects for for both the pre-operation case and for post-operation
  * updates.
  * 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/QueryOperationContext.java
----------------------------------------------------------------------
@@ -15,12 +15,12 @@
 
 /**
- * Encapsulates an {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#PUT} region operation having both key
+ * Encapsulates an {@link org.apache.geode.cache.operations.OperationContext.OperationCode#PUT} region operation having both key
  * and value objects for for both the pre-operation case and for post-operation
  * updates.
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/RegionClearOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/RegionClearOperationContext.java
index f3ac414..188df25 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/RegionClearOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/RegionClearOperationContext.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_CLEAR} operation for both the
  * pre-operation and post-operation cases.
  * 
  * @since GemFire 5.5

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/RegionCreateOperationContext.java
----------------------------------------------------------------------
@@ -15,11 +15,11 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_CLEAR} operation for both the
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#REGION_CLEAR} operation for both the
  * pre-operation and post-operation cases.
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/RegionCreateOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/RegionCreateOperationContext.java
index 4b92ae9..9965eef 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/RegionCreateOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/RegionCreateOperationContext.java
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_CREATE} operation for both the
  * pre-operation and post-operation cases.
  * 
  * @since GemFire 5.5

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/RegionDestroyOperationContext.java
----------------------------------------------------------------------
@@ -15,10 +15,10 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_CREATE} operation for both the
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#REGION_CREATE} operation for both the
  * pre-operation and post-operation cases.
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/RegionDestroyOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/RegionDestroyOperationContext.java
index b2d19c1..d5b7b9a 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/RegionDestroyOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/RegionDestroyOperationContext.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_DESTROY} operation for both the
  * pre-operation and post-operation cases.
  * 
  * @since GemFire 5.5

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/RegionOperationContext.java
----------------------------------------------------------------------
@@ -15,11 +15,11 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_DESTROY} operation for both the
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#REGION_DESTROY} operation for both the
  * pre-operation and post-operation cases.
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/RegionOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/RegionOperationContext.java
index c631a78..49c0338 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/RegionOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/RegionOperationContext.java
@@ -15,14 +15,14 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 
 /**
  * Encapsulates a region-level operation in both the pre-operation and
  * post-operation cases. The operations this class encapsulates are
- * {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_CLEAR} 
- * and {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_DESTROY}.
+ * {@link org.apache.geode.cache.operations.OperationContext.OperationCode#REGION_CLEAR} 
+ * and {@link org.apache.geode.cache.operations.OperationContext.OperationCode#REGION_DESTROY}.
  * 
  * @since GemFire 5.5
  */
@@ -50,8 +50,8 @@ public abstract class RegionOperationContext extends OperationContext {
    * object.
    * 
    * @return The <code>OperationCode</code> of this operation. This is one of
    *         {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_CLEAR} or
    *         {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_DESTROY}.
    */
   @Override
   public abstract OperationCode getOperationCode();

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/RegisterInterestOperationContext.java
----------------------------------------------------------------------
@@ -50,8 +50,8 @@ public abstract class RegionOperationContext extends OperationContext {
    * 
    * @return The <code>OperationCode</code> of this operation. This is one of
-   *         {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_CLEAR} or
-   *         {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGION_DESTROY}.
+   *         {@link org.apache.geode.cache.operations.OperationContext.OperationCode#REGION_CLEAR} or
+   *         {@link org.apache.geode.cache.operations.OperationContext.OperationCode#REGION_DESTROY}.
    */
   @Override
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/RegisterInterestOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/RegisterInterestOperationContext.java
index f5cda63..845ce5b 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/RegisterInterestOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/RegisterInterestOperationContext.java
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
-import com.gemstone.gemfire.cache.InterestResultPolicy;
+import org.apache.geode.cache.InterestResultPolicy;
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGISTER_INTEREST} region operation for
  * the pre-operation case.
  * 
  * @since GemFire 5.5

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/RemoveAllOperationContext.java
----------------------------------------------------------------------
@@ -15,12 +15,12 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REGISTER_INTEREST} region operation for
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#REGISTER_INTEREST} region operation for
  * the pre-operation case.
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/RemoveAllOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/RemoveAllOperationContext.java
index c33d85d..b5c9f44 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/RemoveAllOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/RemoveAllOperationContext.java
@@ -15,15 +15,15 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 import java.util.Collection;
 import java.util.Collections;
 
-import com.gemstone.gemfire.cache.operations.OperationContext;
+import org.apache.geode.cache.operations.OperationContext;
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REMOVEALL} operation for both the
  * pre-operation and post-operation cases.
  * 
  * @since GemFire 8.1

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/StopCQOperationContext.java
----------------------------------------------------------------------
@@ -15,15 +15,15 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#REMOVEALL} operation for both the
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#REMOVEALL} operation for both the
  * pre-operation and post-operation cases.
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/StopCQOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/StopCQOperationContext.java
index eae3ec5..064bd96 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/StopCQOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/StopCQOperationContext.java
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 import java.util.Set;
 
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#STOP_CQ} operation for the pre-operation
  * case.
  * 
  * @since GemFire 5.5

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/UnregisterInterestOperationContext.java
----------------------------------------------------------------------
@@ -15,13 +15,13 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#STOP_CQ} operation for the pre-operation
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#STOP_CQ} operation for the pre-operation
  * case.
  * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/operations/UnregisterInterestOperationContext.java b/geode-core/src/main/java/org/apache/geode/cache/operations/UnregisterInterestOperationContext.java
index 868d455..15bf9cb 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/operations/UnregisterInterestOperationContext.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/operations/UnregisterInterestOperationContext.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.operations;
+package org.apache.geode.cache.operations;
 
 
 /**
  * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#UNREGISTER_INTEREST} region operation for
  * the pre-operation case.
  * 
  * @since GemFire 5.5

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/cache/operations/internal/GetOperationContextImpl.java
----------------------------------------------------------------------
@@ -15,11 +15,11 @@
 
 /**
- * Encapsulates a {@link com.gemstone.gemfire.cache.operations.OperationContext.OperationCode#UNREGISTER_INTEREST} region operation for
+ * Encapsulates a {@link org.apache.geode.cache.operations.OperationContext.OperationCode#UNREGISTER_INTEREST} region operation for
  * the pre-operation case.
  * 